/*
 * @package netNotes
 * @author Sebastian Tschan
 * @copyright (c) Sebastian Tschan
 * @license GNU General Public License
 * @link https://blueimp.net/mozilla/
 */

let netNotes = {
	prefs: Application.extensions.get('netNotes@blueimp.net').prefs,
	
	initialize: function() {
		netNotes.prefs.get('notesView').events.addListener(
			'change',
			netNotes.updateViewCommand
		);
		netNotes.prefs.get('showStatusbarIcon').events.addListener(
			'change',
			netNotes.updateStatusbarIcon
		);
		netNotes.prefs.get('keyboardShortcut').events.addListener(
			'change',
			netNotes.updateKeyboardShortcut
		);
		netNotes.updateViewCommand();
		netNotes.updateStatusbarIcon();
		netNotes.updateKeyboardShortcut();
	},
	
	finalize: function() {
		netNotes.prefs.get('notesView').events.removeListener(
			'change',
			netNotes.updateViewCommand
		);
		netNotes.prefs.get('showStatusbarIcon').events.removeListener(
			'change',
			netNotes.updateStatusbarIcon
		);
		netNotes.prefs.get('keyboardShortcut').events.removeListener(
			'change',
			netNotes.updateKeyboardShortcut
		);
	},

	toggleBottomBar: function() {
		var splitter = document.getElementById('netNotesBottomBarSplitter');
		var box = document.getElementById('netNotesBottomBarBox');
		var bar = document.getElementById('netNotesBottomBar');	
		if(!box.hidden) {
			bar.setAttribute('src', 'about:blank');
			box.hidden = true;
			splitter.hidden = true;
			return;
		}
		box.hidden = false;
		splitter.hidden = false;
		var url = document.getElementById('viewNetNotesSidebar').getAttribute('sidebarurl');
		bar.setAttribute('src', url);
	},

	updateViewCommand: function() {
		document.getElementById('viewNetNotes').setAttribute(
			'command',
			netNotes.prefs.get('notesView').value
		);
	},
	
	updateStatusbarIcon: function() {
		document.getElementById('netNotesStatusbarIcon').setAttribute(
			'hidden',
			!netNotes.prefs.get('showStatusbarIcon').value
		);
	},
	
	updateKeyboardShortcut: function() {
		var netNotesKey = document.getElementById('netNotesKey');
		if(netNotesKey) {
			const Cc = Components.classes;
			const Ci = Components.interfaces;
			var netNotesPrefs2 = Cc['@mozilla.org/preferences-service;1']
										.getService(Ci.nsIPrefService)
										.getBranch('extensions.netNotes@blueimp.net.');
			var items = netNotesPrefs2
						.getComplexValue('keyboardShortcut',Ci.nsIPrefLocalizedString)
						.data.split('+');
			if(items[0]) {
				// Remove the last element and save it as key:
				var key = items.pop();
				// Check if the key is a keycode:
				if(key.indexOf('VK') == 0) {
					netNotesKey.removeAttribute('key');
					netNotesKey.setAttribute('keycode',key);
				} else {
					netNotesKey.removeAttribute('keycode');
					netNotesKey.setAttribute('key',key);
				}
				// The remaining items are the modifiers:
				if(!items.length) {
					netNotesKey.removeAttribute('modifiers');
				} else {
					netNotesKey.setAttribute('modifiers',items.join(' '));
				}
			} else {
				netNotesKey.removeAttribute('key');
				netNotesKey.removeAttribute('keycode');
				netNotesKey.removeAttribute('modifiers');
			}
		}
	}
};

window.addEventListener('load', netNotes.initialize, false);
window.addEventListener('unload', netNotes.finalize, false);